===================
Sample tobiko.conf
===================

This sample configuration can also be viewed in `the raw format
<../../_static/config-samples/tobiko.conf.sample>`_.

.. literalinclude:: ../../_static/config-samples/tobiko.conf.sample
